@@ -1,10 +1,25 @@
+#
+#  This file is part of Sequana software
+#
+#  Copyright (c) 2016-2021 - Sequana Development Team
+#
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  website: https://github.com/sequana/sequana
+#  documentation: http://sequana.readthedocs.io
+#
+##############################################################################
 import sys
 import os
 import argparse
+import subprocess
 
 from sequana_pipetools.options import *
+from sequana_pipetools.options import before_pipeline
 from sequana_pipetools.misc import Colors
 from sequana_pipetools.info import sequana_epilog, sequana_prolog
+from sequana_pipetools import SequanaManager
 
 col = Colors()
 
@@ -18,6 +33,7 @@ class Options(argparse.ArgumentParser):
             epilog=epilog,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter
         )
+
         # add a new group of options to the parser
         so = SlurmOptions()
         so.add_options(self)
@@ -60,6 +76,9 @@ class Options(argparse.ArgumentParser):
         pipeline_group.add_argument("--create-bigwig", action="store_true",
             help="create the bigwig files from the BAM files" )
 
+        self.add_argument("--run", default=False, action="store_true",
+            help="execute the pipeline directly")
+
     def parse_args(self, *args):
         args_list = list(*args)
         if "--from-project" in args_list:
@@ -80,15 +99,11 @@ def main(args=None):
         args = sys.argv
 
     # whatever needs to be called by all pipeline before the options parsing
-    from sequana_pipetools.options import before_pipeline
     before_pipeline(NAME)
 
     # option parsing including common epilog
     options = Options(NAME, epilog=sequana_epilog).parse_args(args[1:])
 
-
-    from sequana.pipelines_common import SequanaManager
-
     # the real stuff is here
     manager = SequanaManager(options, NAME)
 
@@ -113,15 +128,14 @@ def main(args=None):
                 logger.error("The annotation file must end with .gbk or .gff or .gff3. You provided {}".format(cfg.annotation_file))
                 sys.exit(1)
             cfg['sequana_coverage']['genbank_file'] = cfg.annotation_file
+        else:
+            cfg.snpeff.do = False
+            cfg['sequana_coverage']['genbank_file'] = ""
 
         cfg['sequana_coverage']['do'] = options.do_coverage
         cfg['sequana_coverage']["circular"] = options.circular
-
-
         cfg['joint_freebayes']['do'] = options.do_joint_calling
-    
-
-        cfg['bwa_mem_ref']['threads'] = options.threads
+        cfg['bwa_mem']['threads'] = options.threads
         cfg['freebayes']['ploidy'] = options.freebayes_ploidy
 
         cfg.reference_file = os.path.abspath(options.reference)
@@ -134,6 +148,8 @@ def main(args=None):
     # file and save it.
     manager.teardown()
 
+    if options.run:
+        subprocess.Popen(["sh", '{}.sh'.format(NAME)], cwd=options.workdir)
 
 if __name__ == "__main__":
     main()
